@@ -311,12 +311,40 @@ class ComponentReference:
 
     @cached_property
     def jrl(self) -> str:
+        """JRL of this component reference"""
         if not self.is_accessible:
             raise NotFound()
+        return self._calculate_jrl()
+
+    @cached_property
+    def jrl_absolute(self) -> str:
+        """JRL of this component reference including full component exec_name
+
+        Usefull for generating links that can be passed and displayed by
+        other components.
+        """
+        if not self.is_accessible:
+            raise NotFound()
+        return self._calculate_jrl(True)
+
+    def _calculate_jrl(self, is_absolute: bool = False) -> str:
+        """Returns jrl of the component reference
+
+        Absolute jrl are in form $jmb.component(exec_name).call(action) even
+        if action is on current component. Thay are usefull when link is
+        created by one and passed to other component to be rendered in HTML.
+
+        - is_absolute(bool): Should JRL include exec_path of the component.
+          Default False.
+        """
+        name = self.name
+        if is_absolute and name == ".":
+            name = self.exec_name
+
         jrl = (
             "component{reset}('{name}'{kwargs}{key})".format(
                 reset="_reset" if not self.merge_existing_params else "",
-                name=self.name,
+                name=name,
                 key=f",key='{self.key}'" if self._key else "",
                 kwargs=",{}".format(
                     re.sub(
@@ -328,7 +356,7 @@ class ComponentReference:
                 if self.state_kwargs
                 else "",
             )
-            if self.name != "."
+            if name != "."
             else ""
         )
         jrl += (
@@ -387,42 +415,55 @@ class ComponentReference:
     def execute(self):
         """Calls all necessary init, display and call components to execute this component reference
         inside current jembe processor.
+
+        When executing chained component references first call all initialise and then all action
+        commands in reverse order to avoid unecessary component renderes/displays.
         """
         if self.exec_name in self.processor.components_marked_for_removal:
             raise JembeError(
                 f"Cant display component '{self.exec_name}' marked for removal in parent component template!"
             )
-        if self.parent_reference != self:
-            self.parent_reference.execute()
+        current_reference = self
+        reference_chain = [current_reference]
+        while current_reference.parent_reference != current_reference:
+            current_reference = current_reference.parent_reference
+            reference_chain.append(current_reference)
+        reference_chain.reverse()
 
-        self.processor.add_command(
-            InitialiseCommand(self.exec_name, self.kwargs, self.merge_existing_params),
-            end=True,
-        )
-        # self._component_instance = None  # stop using component from is_accessible check
-
-        # call action command is put in que to be executed latter
-        # if this command raises exception parent should chach it and call display
-        # with appropriate template
-        if self.action == ComponentConfig.DEFAULT_DISPLAY_ACTION:
-            self.processor.add_command(
-                CallDisplayCommand(
-                    self.exec_name,
-                    not self.merge_existing_params,
-                    displayed_by_exec_name=self.caller_exec_name,
-                ),
-                end=True,
-            )
-        else:
-            self.processor.add_command(
-                CallActionCommand(
-                    self.exec_name,
-                    self.action,
-                    self.action_args,
-                    self.action_kwargs,
-                ),
-                end=True,
+        init_commands = []
+        action_commands = []
+        for creference in reference_chain:
+            init_commands.append(
+                InitialiseCommand(
+                    creference.exec_name,
+                    creference.kwargs,
+                    creference.merge_existing_params,
+                )
             )
+            # call action command is put in que to be executed latter
+            # if this command raises exception parent should chach it and call display
+            # with appropriate template
+            if creference.action == ComponentConfig.DEFAULT_DISPLAY_ACTION:
+                action_commands.append(
+                    CallDisplayCommand(
+                        creference.exec_name,
+                        not creference.merge_existing_params,
+                        displayed_by_exec_name=creference.caller_exec_name,
+                    )
+                )
+            else:
+                action_commands.append(
+                    CallActionCommand(
+                        creference.exec_name,
+                        creference.action,
+                        creference.action_args,
+                        creference.action_kwargs,
+                    )
+                )
+        for init_cmd in init_commands:
+            self.processor.add_command(init_cmd, end=True)
+        for act_cmd in reversed(action_commands):
+            self.processor.add_command(act_cmd, end=True)
 
     def __call__(self) -> str:
         """
@@ -436,7 +477,7 @@ class ComponentReference:
         return Markup(f'<template jmb-placeholder="{self.exec_name}"></template>')
 
     def key(self, key: str) -> "jembe.ComponentReference":
-        self._key = key
+        self._key = str(key)
         return self
 
     def call(self, action: str, *args, **kwargs) -> "jembe.ComponentReference":
@@ -866,7 +907,9 @@ class Component(metaclass=ComponentMeta):
         return value
 
     @classmethod
-    def load_init_param(cls, config: "jembe.ComponentConfig", name: str, value: Any) -> Any:
+    def load_init_param(
+        cls, config: "jembe.ComponentConfig", name: str, value: Any
+    ) -> Any:
         """
         load and Decode init/state param received via json call to be uset to initialise in __init__.
         param_value is decoded from json received from client.
@@ -1079,9 +1122,22 @@ class Component(metaclass=ComponentMeta):
             f'<template jmb-placeholder-permanent="{self.exec_name}/{_jmb_copmonent_name}"></template>'
         )
 
-    def emit(self, _jmb_event_name: str, **params) -> "EmitCommand":
+    def emit(
+        self, _jmb_event_name: str, _deferred: bool = False, **params
+    ) -> "EmitCommand":
+        """Emits event with message to other components
+
+        Args:
+            _jmb_event_name (str): event name
+            _as_last (bool, optional): Emit event las when all other commands are executed. Defaults to False.
+            params: message parametes passed to reciving components
+
+        Returns:
+            EmitCommand: _description_
+        """
         processor = get_processor()
         emmit_command = EmitCommand(self.exec_name, _jmb_event_name, params)
+        emmit_command.is_deferred = _deferred
         processor.add_command(emmit_command)
         return emmit_command
 
@@ -1152,7 +1208,7 @@ class Component(metaclass=ComponentMeta):
 
         # Creates new commands to init and display for redirect components
         # and puts in processenig que
-        component_ref()
+        component_ref.execute()
 
     def ac_allow(self, *action_names):
         """
