@@ -116,25 +116,22 @@ class File(JembeInitParamSupport):
             "/".join((temp_subdir, subdir)) if subdir is not None else temp_subdir,
         )
 
-    def move_to_public(self, subdir: str = ""):
+    def move_to_public(self, subdir: str = "") -> "jembe.File":
         file = self.move_to(get_public_storage(), subdir)
-        self.storage = file.storage
-        self.path = file.path
+        return file
 
-    def move_to_private(self, subdir: str = ""):
+    def move_to_private(self, subdir: str = "") -> "jembe.File":
         file = self.move_to(get_private_storage(), subdir)
         file.grant_access()
-        self.storage = file.storage
-        self.path = file.path
+        return file
 
-    def move_to_temp(self, subdir: Optional[str] = None):
+    def move_to_temp(self, subdir: Optional[str] = None) -> "jembe.File":
         temp_subdir = self.storage._get_default_temp_subdir()
         file = self.move_to(
             get_temp_storage(),
             "/".join((temp_subdir, subdir)) if subdir is not None else temp_subdir,
         )
-        self.storage = file.storage
-        self.path = file.path
+        return file
 
     def remove(self):
         self.storage.remove(self.path)
@@ -212,6 +209,9 @@ class File(JembeInitParamSupport):
     def __hash__(self) -> int:
         return hash((self.storage, self.path))
 
+    def __copy__(self) -> "jembe.File":
+        return File(self.storage, self.path)
+
 
 class Storage(ABC):
     class Type(Enum):
@@ -633,13 +633,13 @@ class DiskStorage(Storage):
         elif isinstance(file, IOBase):
             if filename is None:
                 raise ValueError(
-                    "Storge '{}': Filename is required when storing BufferedIOBase".format(
+                    "Storage '{}': Filename is required when storing BufferedIOBase".format(
                         self.name
                     )
                 )
             sfn = self._get_unique_filename(filename, subdir)
             os.makedirs(os.path.join(self.folder, subdir), exist_ok=True)
-            new_file = File(self, os.path.join(self.folder, subdir, sfn))
+            new_file = File(self, os.path.join(subdir, sfn))
             if isinstance(file, (BufferedIOBase, RawIOBase)):
                 fio = new_file.open(mode="wb")
                 file.seek(0)
