@@ -114,6 +114,11 @@ class Command(ABC):
         self.processor: "Processor"
         self.is_mounted = False
 
+        # Flag to defer execution.
+        # Deferred command are executed after all other commad in processor que
+        # this flag is check only when command is added to quey
+        self.is_deferred = False
+
     def mount(self: TCommand, processor: "Processor") -> TCommand:
         if self.is_mounted:
             raise JembeError("Command {} is already mounted".format(self.__repr__()))
@@ -274,6 +279,8 @@ class CallDisplayCommand(CallActionCommand):
 
     @cached_property
     def _redisplay_needed(self):
+        if self.component_exec_name in self.processor.components_marked_for_removal:
+            return False
         if self.component_exec_name in self.processor.renderers and not (
             self.force
             or (
@@ -385,6 +392,10 @@ class CallListenerCommand(Command):
         self.event = event
 
     def execute(self):
+        if self.component_exec_name in self.processor.components_marked_for_removal:
+            # Listener should not be executed on components marked for removal
+            return False
+
         component = self.processor.components[self.component_exec_name]
         cconfig = component._config
         if self.listener_name not in cconfig.component_listeners:
@@ -395,15 +406,20 @@ class CallListenerCommand(Command):
             )
 
         # execute listener
+        component_begining_state = component.state.tojsondict(component, True)
         listener_result = getattr(component, self.listener_name)(self.event)
         component._jembe_has_action_or_listener_executed = True
-        if listener_result is None or (
-            isinstance(listener_result, bool) and listener_result == True
-        ):
-            # after executing listener that returns True or None
-            # component should be rendered by executing display
+        # after executing listener that returns:
+        if listener_result is None:
+            # - None: component should be redisplayed only if state is changed in listener
+            if component_begining_state != component.state.tojsondict(component, True):
+                self.processor.add_command(
+                    CallDisplayCommand(component.exec_name), end=True
+                )
+        elif isinstance(listener_result, bool) and listener_result == True:
+            # - True: component should be forced to redisplayed itself
             self.processor.add_command(
-                CallDisplayCommand(component.exec_name, force=listener_result == True),
+                CallDisplayCommand(component.exec_name, force=True),
                 end=True,
             )
         elif isinstance(listener_result, bool) or listener_result == False:
@@ -463,6 +479,7 @@ class EmitCommand(Command):
             - ./component.*                     -> emit to direct child named "component" with any key
             - ./component.key                   -> emit to direct child named "component with key equals "key"
             - ./**/component[.[*|<key>]]        -> emit to child at any level
+            - *                                 -> match to any direct child
             - ..                                -> emit to parent
             - ../component[.[*|<key>]]          -> emit to sibling
             - /**/.                             -> emit to parent at any level
@@ -493,6 +510,9 @@ class EmitCommand(Command):
         )
         execute_over: List[Tuple["jembe.Component", str]] = []
         for exec_name, component in self.processor.components.items():
+            # no components marked for removal
+            if exec_name in self.processor.components_marked_for_removal:
+                continue
             for (
                 listener_method_name,
                 listener,
@@ -619,6 +639,9 @@ class EmitCommand(Command):
     def reemit_over(
         self, reemit_component_exec_name: str
     ) -> List["CallListenerCommand"]:
+        if reemit_component_exec_name in self.processor.components_marked_for_removal:
+            return list()
+
         reemit_component = self.processor.components[reemit_component_exec_name]
         commands = list()
         for (
@@ -880,9 +903,11 @@ class InitialiseCommand(Command):
 
     def __repr__(self):
         try:
-            return "Init({}, {})".format(self.component_exec_name, self.init_params)
+            # return "Init({}, {})".format(self.component_exec_name, self.init_params)
+            return "Init({})".format(self.component_exec_name)
         except:
-            return "Init({}, {})".format(self.component_exec_name, self._init_params)
+            # return "Init({}, {})".format(self.component_exec_name, self._init_params)
+            return "Init({})".format(self.component_exec_name)
 
 
 class ComponentRender(NamedTuple):
@@ -955,6 +980,8 @@ class CommandsQue:
                     )
                 )
             is_deferred_command = caction.deferred
+        elif isinstance(command, EmitCommand) and command.is_deferred:
+            is_deferred_command = True
 
         if is_deferred_command:
             _do_add_command(self.deferred_commands, command, end)
@@ -964,7 +991,7 @@ class CommandsQue:
     def move_commands_to(self, que: Deque["Command"]) -> None:
         """Moves commands from staging que to execution que"""
         while self.deferred_commands:
-            que.append(self.deferred_commands.popleft())
+            que.appendleft(self.deferred_commands.popleft())
         while self.commands:
             que.append(self.commands.popleft())
 
@@ -1012,6 +1039,9 @@ class Processor:
         # direct response if component display returns it
         self._response: Optional["Response"] = None
 
+        # globals
+        self.call_window_open: List[str] = []
+
         # List of init commands without coresponding call command that
         # need to be checked for redisplay depending of other redisplayed compoents
         # on page (when processing x-jembe request)
@@ -1110,13 +1140,20 @@ class Processor:
             # init commands
             updated_init_commands_execnames: List[str] = []
             call_commands_execnames: List[str] = []
+            non_init_commands = []
             for command_data in data["commands"]:
                 command = self._x_jembe_command_factory(command_data)
-                self.add_command(command, end=True)
+                if isinstance(command, InitialiseCommand):
+                    self.add_command(command, end=True)
+                else:
+                    non_init_commands.append(command)
                 if isinstance(command, InitialiseCommand):
                     updated_init_commands_execnames.append(command.component_exec_name)
                 elif isinstance(command, CallActionCommand):
                     call_commands_execnames.append(command.component_exec_name)
+
+            for command in non_init_commands:
+                self.add_command(command, end=True)
             # find all init commands without coresponding call or display command
             self._hanging_init_commands_execnames = [
                 c
@@ -1129,11 +1166,7 @@ class Processor:
                 component_full_name, list()
             )
 
-            self.add_command(
-                CallDisplayCommand(exec_names[-1]),
-                end=True,
-            )
-            for exec_name in exec_names[:-1]:
+            for exec_name in reversed(exec_names):
                 self.add_command(
                     CallDisplayCommand(exec_name),
                     end=True,
@@ -1221,9 +1254,10 @@ class Processor:
                 )
             exec_names.append(exec_name)
 
-        if exec_name not in self.request.path:
-            # dont allow that /mainaaaa open /main.aaaa
-            raise NotFound()
+        # if exec_name not in self.request.path:
+        #     # dont allow that /mainaaaa open /main.aaaa
+        #     import pdb; pdb.set_trace()
+        #     raise NotFound()
         return exec_names
 
     def process_request(self) -> "Processor":
@@ -1312,6 +1346,7 @@ class Processor:
     def _execute_commands(self) -> Optional["Response"]:
         """executes all commands from self._commands que"""
         while self._commands:
+            # print("\tCOMMANDS: ", self._commands)
             response = self._execute_command(self._commands.pop())
             if response is not None:
                 return response
@@ -1333,6 +1368,7 @@ class Processor:
             ):
                 return None
 
+        # print("\nEXEC: ", command)
         try:
             self._processing_command = command
             response = command.execute()
@@ -1406,7 +1442,7 @@ class Processor:
             self.components = backup_current_components
             if current_app.debug or current_app.testing:
                 current_app.logger.warning(
-                    "Exception when initialising component out of proccessing que {}: {}".format(
+                    "DEBUG: Exception when initialising component out of proccessing que {}: {}".format(
                         command, exc.__repr__()
                     )
                 )
@@ -1554,13 +1590,15 @@ class Processor:
                             },
                         )
                     )
-            if self.components_marked_for_removal:
-                ajax_responses.append(
-                    dict(
-                        globals=True,
-                        removeComponents=self.components_marked_for_removal,
-                    )
+            if self.components_marked_for_removal or self.call_window_open:
+                globals = dict(
+                    globals=True,
                 )
+                if self.components_marked_for_removal:
+                    globals["removeComponents"] = self.components_marked_for_removal
+                if self.call_window_open:
+                    globals["callWindowOpen"] = self.call_window_open
+                ajax_responses.append(globals)
             return jsonify(ajax_responses)
         else:
             # for page with components build united response
