@@ -243,13 +243,13 @@ test('call nested component actions', () => {
           "args": [],
           "kwargs": {}
         },
-        {
-          "type": "call",
-          "componentExecName": "/nav",
-          "actionName": "display",
-          "args": [],
-          "kwargs": {}
-        },
+        // {
+        //   "type": "call",
+        //   "componentExecName": "/nav",
+        //   "actionName": "display",
+        //   "args": [],
+        //   "kwargs": {}
+        // },
       ]
     }
   ))
@@ -368,13 +368,13 @@ test("test setting nested component init params", () => {
           },
           mergeExistingParams: true
         },
-        {
-          type: "call",
-          componentExecName: "/test",
-          actionName: "display",
-          args: [],
-          kwargs: {}
-        }
+        // {
+        //   type: "call",
+        //   componentExecName: "/test",
+        //   actionName: "display",
+        //   args: [],
+        //   kwargs: {}
+        // }
       ]
     }
   ))
@@ -417,13 +417,13 @@ test("test setting nested component init params - direct", () => {
           },
           mergeExistingParams: true
         },
-        {
-          type: "call",
-          componentExecName: "/test",
-          actionName: "display",
-          args: [],
-          kwargs: {}
-        }
+        // {
+        //   type: "call",
+        //   componentExecName: "/test",
+        //   actionName: "display",
+        //   args: [],
+        //   kwargs: {}
+        // }
       ]
     }
   ))
@@ -477,7 +477,7 @@ test("test on refresh delay clears all timers", () => {
   buildDocument(`
     <html jmb-name="/test" jmb-data='{"changesUrl":true,"state":{},"url":"/test","actions":{}}'>
       <body>
-        <div id="one" jmb-on:ready.delay.50ms.defer="document.test='one'"></div>
+        <div id="one" jmb-on:ready.delay-t1.500ms.defer="document.test='one'"></div>
       </body>
     </html>
   `)
@@ -491,18 +491,18 @@ test("test on refresh delay clears all timers", () => {
       "dom": `
     <html jmb-name="/test" jmb-data='{"changesUrl":true,"state":{},"url":"/test","actions":{}}'>
       <body>
-        <div id="one" jmb-on:ready.delay.30ms.defer="document.test='two'"></div>
+        <div id="one" jmb-on:ready.delay-t1.300ms.defer="document.test='two'"></div>
       </body>
     </html>
     `},
   ]
-  window.jembeClient.updateDocument(jembeClient.getComponentsFromXResponse(xResponse))
+  window.jembeClient.updateDocument(jembeClient.getComponentsAndGlobalsFromXResponse(xResponse))
   expect(setTimeout).toHaveBeenCalledTimes(2)
-  expect(setTimeout).toHaveBeenNthCalledWith(1, expect.any(Function), 50)
-  expect(setTimeout).toHaveBeenNthCalledWith(2, expect.any(Function), 30)
-  jest.advanceTimersByTime(30)
+  expect(setTimeout).toHaveBeenNthCalledWith(1, expect.any(Function), 500)
+  // expect(setTimeout).toHaveBeenNthCalledWith(2, expect.any(Function), 300)
+  jest.advanceTimersByTime(300)
   expect(document.test).toBe('two')
-  jest.advanceTimersByTime(50)
+  jest.advanceTimersByTime(500)
   expect(document.test).toBe('two')
 
 })
@@ -533,7 +533,7 @@ test("test on refresh delay continue named timers", () => {
   ]
   jest.advanceTimersByTime(1)
   expect(document.test).toBe(undefined)
-  window.jembeClient.updateDocument(jembeClient.getComponentsFromXResponse(xResponse))
+  window.jembeClient.updateDocument(jembeClient.getComponentsAndGlobalsFromXResponse(xResponse))
   expect(setTimeout).toHaveBeenCalledTimes(2)
   expect(setTimeout).toHaveBeenNthCalledWith(1, expect.any(Function), 50)
   expect(setTimeout.mock.calls[1][1]).toBeLessThan(50) 
@@ -602,13 +602,13 @@ test("$jmb.set not deferred shout call display", () => {
           "initParams": { "a": 1 },
           "mergeExistingParams": true
         },
-        {
-          "type": "call",
-          "componentExecName": "/tasks",
-          "actionName": "display",
-          "args": [],
-          "kwargs": {}
-        }
+        // {
+        //   "type": "call",
+        //   "componentExecName": "/tasks",
+        //   "actionName": "display",
+        //   "args": [],
+        //   "kwargs": {}
+        // }
       ]
     }
   ))
@@ -671,13 +671,13 @@ test("$jmb.component chain", () => {
           "args": [],
           "kwargs": {}
         },
-        {
-          "type": "call",
-          "componentExecName": "/main",
-          "actionName": "display",
-          "args": [],
-          "kwargs": {}
-        }
+        // {
+        //   "type": "call",
+        //   "componentExecName": "/main",
+        //   "actionName": "display",
+        //   "args": [],
+        //   "kwargs": {}
+        // }
       ]
     }
   ))
@@ -706,4 +706,19 @@ test("$jmb.component chain", () => {
       ]
     }
   ))
-})
\ No newline at end of file
+})
+test("$updateDom() call", () => {
+  buildDocument(`
+    <html jmb-name="/tasks" jmb-data='{"changesUrl":true,"state":{"a":0},"url":"/tasks","actions":{}}'>
+      <body jmb-on:jembe-test.camel.window.defer="a = a+1; $updateDom()">
+          <div id="testA" jmb-text="a"></div>
+          <button id="buttonA" jmb-on:click.defer="a=a+1; $updateDom()">Increase A</button>
+      </body>
+    </html>
+  `)
+  document.querySelector('#buttonA').click()
+  // window.dispatchEvent(new CustomEvent('jembeTest',{}))
+  expect(window.jembeClient.components['/tasks'].api.$data.a).toBe(1)
+  //test: except(
+
+  })
\ No newline at end of file
